import os

import axipy
from PIL import Image
from PySide2.QtGui import QIcon
from PySide2.QtWidgets import QFileDialog


class ExamplePluginMinimal(axipy.Plugin):
    def __init__(self) -> None:
        self._title: str = self.tr("Конвертация в PNG")

        self._action: axipy.axipy.ActionButton = axipy.ActionButton(
            title=self._title,
            icon=self._get_icon('png.png'),
            on_click=self.convert_to_png,
            tooltip=self.tr("Конвертация изображений в PNG")
        )
        position = axipy.Position(axipy.tr("Основные"), axipy.tr("Команды"))
        position.add(self._action)

    def unload(self) -> None:
        self._action.remove()

    def convert_to_png(self) -> None:
        try:
            files = QFileDialog.getOpenFileNames(caption=self._title)
            for file in files[0]:
                im = Image.open(file)
                if im.mode == '1':
                    palette = [0, 0, 0, 255, 255, 255]
                    im = im.convert('P', colors=2)
                    im.putpalette(palette)
                im.save(file + '.png', format='PNG', optimize=True)
        except Exception as ex:
            axipy.show_message(str(ex), self._title, axipy.DlgIcon.ERROR)

    @staticmethod
    def _get_icon(filename) -> QIcon:
        return QIcon(os.path.join(os.path.dirname(__file__), filename))
